@@ -4,9 +4,9 @@
 
 set -e
 
-# Run in most basic of locales to avoid performance overhead (and risk of bugs)
-# involved in localization, encoding issues etc.  We only do ASCII here.
-export LC_ALL=C
+# Optionally run in "dumb" locale to avoid performance overhead (and risk of
+# bugs) involved in localization, encoding issues etc.  We only do ASCII here.
+#export LC_ALL=C
 
 latest_automake() {
 	for v in "-1.10" "-1.9" "-1.8" "-1.7" "-1.6" "" ; do
@@ -20,7 +20,7 @@ latest_automake() {
 ver="`latest_automake`"
 
 # The VERSION file defines our versioning
-PQXXVERSION=`grep '\<PQXXVERSION\>' VERSION | sed -e 's/^[[:space:]A-Z_]*//' -e 's/[[:space:]]*#.*$//'`
+PQXXVERSION=`./tools/extract_version`
 echo "libpqxx version $PQXXVERSION"
 
 # Generate configure.ac based on current version numbers
@@ -34,6 +34,7 @@ makewinmake() {
 if which python >/dev/null ; then
 	# Use templating system to generate various Makefiles
 	./tools/template2mak.py test/Makefile.am.template test/Makefile.am
+	./tools/template2mak.py test/unit/Makefile.am.template test/unit/Makefile.am
 	makewinmake win32/vc-libpqxx.mak.template win32/vc-libpqxx.mak
 	makewinmake win32/vc-test.mak.template win32/vc-test.mak
 	makewinmake win32/mingw.mak.template win32/MinGW.mak
