@@ -1,7 +1,7 @@
 #define PACKAGE "libpqxx"
 #define PACKAGE_BUGREPORT "Jeroen T. Vermeulen <jtv@xs4all.nl>"
 #define PACKAGE_NAME "libpqxx"
-#define PACKAGE_STRING "libpqxx 2.6.9"
+#define PACKAGE_STRING "libpqxx 3.0"
 #define PACKAGE_TARNAME "libpqxx"
-#define PACKAGE_VERSION "2.6.9"
-#define VERSION "2.6.9"
+#define PACKAGE_VERSION "3.0"
+#define VERSION "3.0"
