@@ -6,7 +6,7 @@
  *   DESCRIPTION
  *      implementation of bytea (binary string) conversions
  *
- * Copyright (c) 2003-2006, Jeroen T. Vermeulen <jtv@xs4all.nl>
+ * Copyright (c) 2003-2007, Jeroen T. Vermeulen <jtv@xs4all.nl>
  *
  * See COPYING for copyright license.  If you did not receive a file called
  * COPYING with this source code, please notify the distributor of this mistake,
@@ -16,6 +16,7 @@
  */
 #include "pqxx/compiler-internal.hxx"
 
+#include <cstring>
 #include <new>
 #include <stdexcept>
 
@@ -30,7 +31,7 @@ using namespace pqxx::internal;
 namespace
 {
 // Convert textual digit to value
-inline char DV(unsigned char d) { return digit_to_number(char(d)); }
+inline int DV(unsigned char d) { return digit_to_number(char(d)); }
 }
 
 pqxx::binarystring::binarystring(const result::field &F) :
