@@ -7,7 +7,7 @@
  *      implementation of the pqxx::robusttransaction class.
  *   pqxx::robusttransaction is a slower but safer transaction class
  *
- * Copyright (c) 2002-2006, Jeroen T. Vermeulen <jtv@xs4all.nl>
+ * Copyright (c) 2002-2007, Jeroen T. Vermeulen <jtv@xs4all.nl>
  *
  * See COPYING for copyright license.  If you did not receive a file called
  * COPYING with this source code, please notify the distributor of this mistake,
@@ -181,9 +181,16 @@ void pqxx::basic_robusttransaction::CreateLogTable()
   if (conn().supports(connection_base::cap_create_table_with_oids))
     CrTab += ") WITH OIDS";
   else
-    CrTab += ", CONSTRAINT identity UNIQUE(oid))";
-
-  try { DirectExec(CrTab.c_str(), 1); } catch (const exception &) { }
+    CrTab += string(", CONSTRAINT pqxxlog_identity_") + conn().username() +
+	     " UNIQUE(oid))";
+  try
+  {
+    DirectExec(CrTab.c_str(), 1);
+  } catch (const exception &e)
+  {
+    conn().process_notice(
+	"Could not create transaction log table: " + string(e.what()));
+  }
 }
 
 
@@ -209,12 +216,15 @@ void pqxx::basic_robusttransaction::CreateTransactionRecord()
   catch (const sql_error &e) { throw sql_error(Fail+e.what(), Insert); }
   catch (const broken_connection &) { throw; }
   catch (const bad_alloc &) { throw; }
-  catch (const out_of_range &e) { throw out_of_range(Fail+e.what()); }
   catch (const range_error &e) { throw range_error(Fail+e.what()); }
-  catch (const invalid_argument &e) { throw invalid_argument(Fail+e.what()); }
-  catch (const runtime_error &e) { throw runtime_error(Fail+e.what()); }
+  catch (const out_of_range &e) { throw range_error(Fail+e.what()); }
+  catch (const argument_error &e) { throw argument_error(Fail+e.what()); }
+  catch (const invalid_argument &e) { throw argument_error(Fail+e.what()); }
+  catch (const failure &e) { throw failure(Fail+e.what()); }
+  catch (const runtime_error &e) { throw failure(Fail+e.what()); }
   catch (const domain_error &e) { throw domain_error(Fail+e.what()); }
-  catch (const logic_error &e) { throw logic_error(Fail+e.what()); }
+  catch (const usage_error &e) { throw usage_error(Fail+e.what()); }
+  catch (const logic_error &e) { throw usage_error(Fail+e.what()); }
   catch (const exception &e) { throw sql_error(Fail+e.what(), Insert); }
 
   if (m_ID == oid_none)
