@@ -7,7 +7,7 @@
  *      implementation of the pqxx::tablewriter class.
  *   pqxx::tablewriter enables optimized batch updates to a database table
  *
- * Copyright (c) 2001-2006, Jeroen T. Vermeulen <jtv@xs4all.nl>
+ * Copyright (c) 2001-2007, Jeroen T. Vermeulen <jtv@xs4all.nl>
  *
  * See COPYING for copyright license.  If you did not receive a file called
  * COPYING with this source code, please notify the distributor of this mistake,
@@ -38,7 +38,7 @@ pqxx::tablewriter::tablewriter(transaction_base &T,
 pqxx::tablewriter::~tablewriter() throw ()
 {
 #ifdef PQXX_QUIET_DESTRUCTORS
-  internal::disable_noticer Quiet(m_Trans.conn());
+  disable_noticer Quiet(m_Trans.conn());
 #endif
   try
   {
@@ -64,19 +64,18 @@ pqxx::tablewriter &pqxx::tablewriter::operator<<(pqxx::tablereader &R)
 {
   string Line;
   // TODO: Can we do this in binary mode? (Might require protocol version check)
-  while (R.get_raw_line(Line))
-  {
-    if (!Line.empty() && (Line[Line.size()-1]=='\n')) Line.erase(Line.size()-1);
-    WriteRawLine(Line);
-  }
-
+  while (R.get_raw_line(Line)) write_raw_line(Line);
   return *this;
 }
 
 
-void pqxx::tablewriter::WriteRawLine(const PGSTD::string &Line)
+void pqxx::tablewriter::write_raw_line(const PGSTD::string &Line)
 {
-  m_Trans.WriteCopyLine(Line);
+  const string::size_type len = Line.size();
+  m_Trans.WriteCopyLine(
+	(!len || Line[len-1] != '\n') ?
+	Line :
+	string(Line, 0, len-1));
 }
 
 
@@ -122,9 +121,9 @@ inline char escapechar(char i)
   return r;
 }
 
-inline bool ishigh(char i)
+inline bool unprintable(char i)
 {
-  return (i & 0x80) != 0;
+  return i < ' ' || i > '~';
 }
 
 inline char tooctdigit(unsigned int i, int n)
@@ -152,9 +151,9 @@ string pqxx::internal::Escape(const string &s, const string &null)
       R += '\\';
       R += e;
     }
-    else if (ishigh(c))
+    else if (unprintable(c))
     {
-      R += '\\';
+      R += "\\\\";
       unsigned char u=c;
       for (int n=2; n>=0; --n) R += tooctdigit(u,n);
     }
